@@ -33,6 +33,8 @@ def main():
     add('-i', 'configs_directory')
     add('-o', 'out_directory')
     add('-l', 'language')
+    add('-f', 'formats')
+    add('-j', 'join_to_one_file')
     add('-side')
     add('-data', 'data_directory')
     add('-data_out', 'out_data_directory')
@@ -46,6 +48,7 @@ def main():
     add('-php_validate')
     add('-test_script')
     add('-test_script_args')
+    add('-auto_registration')
 
     mlc = Mlc(**args)
     mlc.generate()
